@@ -14,7 +14,7 @@ var quicktext = {
   mPickedIndex:         null,
   mOS:                  "WINNT"
 ,
-  init: function()
+  init: async function()
   {
     if (!this.mLoaded)
     {
@@ -28,7 +28,7 @@ var quicktext = {
       this.mOS = appInfo.OS;
 
       gQuicktext.addObserver(this);
-      var hasLoadedBefore = !gQuicktext.loadSettings(false);
+      var hasLoadedBefore = !(await gQuicktext.loadSettings(false));
 
       var states = gQuicktext.collapseState;
       if (states != "")
@@ -262,15 +262,6 @@ var quicktext = {
     else
       this.noGeneralChangeMade(aIndex);
   }
-,
-  onResize: function()
-  {
-    let textElement = document.getElementById("text");
-    textElement.style.height = (textElement.parentElement.clientHeight - 5) + "px";
-
-    let scriptElement = document.getElementById("script");
-    scriptElement.style.height = (scriptElement.parentElement.clientHeight - 5) + "px";
-  }
 ,
   checkForTextChanges: function(aIndex)
   {
@@ -870,8 +861,7 @@ var quicktext = {
         elements[i].hidden = false;
       else
         elements[i].hidden = true;
-    }
-    this.onResize();    
+    } 
   }
 ,
 
@@ -1417,6 +1407,11 @@ var quicktext = {
   {
     gQuicktext.openHomepage();
   }
+,
+  resetCounter: function()
+  {
+    notifyTools.notifyBackground({command:"setPref", pref: "counter", value: 0});
+  }
 ,
   shortcutModifierChange: function()
   {
